@@ -139,7 +139,7 @@ class HTTPMessage(mimetools.Message):
 
         self.dict = {}
         self.unixfrom = ''
-        self.headers = list = []
+        self.headers = hlist = []
         self.status = ''
         headerseen = ""
         firstline = 1
@@ -148,7 +148,7 @@ class HTTPMessage(mimetools.Message):
             unread = self.fp.unread
         elif self.seekable:
             tell = self.fp.tell
-        while 1:
+        while True:
             if tell:
                 try:
                     startofline = tell()
@@ -168,8 +168,7 @@ class HTTPMessage(mimetools.Message):
                 # XXX Not sure if continuation lines are handled properly
                 # for http and/or for repeating headers
                 # It's a continuation line.
-                list.append(line)
-                x = self.dict[headerseen] + "\n " + line.strip()
+                hlist.append(line)
                 self.addcontinue(headerseen, line.strip())
                 continue
             elif self.iscomment(line):
@@ -181,7 +180,7 @@ class HTTPMessage(mimetools.Message):
             headerseen = self.isheader(line)
             if headerseen:
                 # It's a legal header line, save it.
-                list.append(line)
+                hlist.append(line)
                 self.addheader(headerseen, line[len(headerseen)+1:].strip())
                 continue
             else:
@@ -209,10 +208,11 @@ class HTTPResponse:
 
     # See RFC 2616 sec 19.6 and RFC 1945 sec 6 for details.
 
-    def __init__(self, sock, debuglevel=0, strict=0):
+    def __init__(self, sock, debuglevel=0, strict=0, method=None):
         self.fp = sock.makefile('rb', 0)
         self.debuglevel = debuglevel
         self.strict = strict
+        self._method = method
 
         self.msg = None
 
@@ -231,6 +231,10 @@ class HTTPResponse:
         line = self.fp.readline()
         if self.debuglevel > 0:
             print "reply:", repr(line)
+        if not line:
+            # Presumably, the server closed the connection before
+            # sending a valid response.
+            raise BadStatusLine(line)
         try:
             [version, status, reason] = line.split(None, 2)
         except ValueError:
@@ -265,12 +269,12 @@ class HTTPResponse:
             return
 
         # read until we get a non-100 response
-        while 1:
+        while True:
             version, status, reason = self._read_status()
             if status != 100:
                 break
             # skip the header from the 100 response
-            while 1:
+            while True:
                 skip = self.fp.readline().strip()
                 if not skip:
                     break
@@ -311,20 +315,7 @@ class HTTPResponse:
             self.chunked = 0
 
         # will the connection close at the end of the response?
-        conn = self.msg.getheader('connection')
-        if conn:
-            conn = conn.lower()
-            # a "Connection: close" will always close the connection. if we
-            # don't see that and this is not HTTP/1.1, then the connection will
-            # close unless we see a Keep-Alive header.
-            self.will_close = conn.find('close') != -1 or \
-                              ( self.version != 11 and \
-                                not self.msg.getheader('keep-alive') )
-        else:
-            # for HTTP/1.1, the connection will always remain open
-            # otherwise, it will remain open IFF we see a Keep-Alive header
-            self.will_close = self.version != 11 and \
-                              not self.msg.getheader('keep-alive')
+        self.will_close = self._check_close()
 
         # do we have a Content-Length?
         # NOTE: RFC 2616, S4.4, #3 says we ignore this if tr_enc is "chunked"
@@ -340,7 +331,8 @@ class HTTPResponse:
         # does the body have a fixed length? (of zero)
         if (status == 204 or            # No Content
             status == 304 or            # Not Modified
-            100 <= status < 200):       # 1xx codes
+            100 <= status < 200 or      # 1xx codes
+            self._method == 'HEAD'):
             self.length = 0
 
         # if the connection remains open, and we aren't using chunked, and
@@ -351,6 +343,30 @@ class HTTPResponse:
            self.length is None:
             self.will_close = 1
 
+    def _check_close(self):
+        if self.version == 11:
+            # An HTTP/1.1 proxy is assumed to stay open unless
+            # explicitly closed.
+            conn = self.msg.getheader('connection')
+            if conn and conn.lower().find("close") >= 0:
+                return True
+            return False
+
+        # An HTTP/1.0 response with a Connection header is probably
+        # the result of a confused proxy.  Ignore it.
+
+        # For older HTTP, Keep-Alive indiciates persistent connection.
+        if self.msg.getheader('keep-alive'):
+            return False
+
+        # Proxy-Connection is a netscape hack.
+        pconn = self.msg.getheader('proxy-connection')
+        if pconn and pconn.lower().find("keep-alive") >= 0:
+            return False
+
+        # otherwise, assume it will close
+        return True
+
     def close(self):
         if self.fp:
             self.fp.close()
@@ -401,7 +417,7 @@ class HTTPResponse:
 
         # XXX This accumulates chunks by repeated string concatenation,
         # which is not efficient as the number or size of chunks gets big.
-        while 1:
+        while True:
             if chunk_left is None:
                 line = self.fp.readline()
                 i = line.find(';')
@@ -431,13 +447,12 @@ class HTTPResponse:
 
         # read and discard trailer up to the CRLF terminator
         ### note: we shouldn't have any trailers!
-        while 1:
+        while True:
             line = self.fp.readline()
             if line == '\r\n':
                 break
 
         # we read everything; close the "file"
-        # XXX Shouldn't the client close the file?
         self.close()
 
         return value
@@ -461,8 +476,8 @@ class HTTPResponse:
             chunk = self.fp.read(amt)
             if not chunk:
                 raise IncompleteRead(s)
-            s = s + chunk
-            amt = amt - len(chunk)
+            s += chunk
+            amt -= len(chunk)
         return s
 
     def getheader(self, name, default=None):
@@ -487,6 +502,7 @@ class HTTPConnection:
         self._buffer = []
         self.__response = None
         self.__state = _CS_IDLE
+        self._method = None
 
         self._set_hostport(host, port)
         if strict is not None:
@@ -587,8 +603,7 @@ class HTTPConnection:
         `url' specifies the object being requested, e.g. '/index.html'.
         """
 
-        # check if a prior response has been completed
-        # XXX What if it hasn't?
+        # if a prior response has been completed, then forget about it.
         if self.__response and self.__response.isclosed():
             self.__response = None
 
@@ -616,6 +631,8 @@ class HTTPConnection:
         else:
             raise CannotSendRequest()
 
+        # Save the method we use, we need it later in the response phase
+        self._method = method
         if not url:
             url = '/'
         str = '%s %s %s' % (method, url, self._http_vsn_str)
@@ -645,11 +662,11 @@ class HTTPConnection:
                     nil, netloc, nil, nil, nil = urlsplit(url)
 
                 if netloc:
-                    self.putheader('Host', netloc)
+                    self.putheader('Host', netloc.encode("idna"))
                 elif self.port == HTTP_PORT:
-                    self.putheader('Host', self.host)
+                    self.putheader('Host', self.host.encode("idna"))
                 else:
-                    self.putheader('Host', "%s:%s" % (self.host, self.port))
+                    self.putheader('Host', "%s:%s" % (self.host.encode("idna"), self.port))
 
             # note: we are assuming that clients will not attempt to set these
             #       headers since *this* library must deal with the
@@ -718,7 +735,7 @@ class HTTPConnection:
 
         if body:
             self.putheader('Content-Length', str(len(body)))
-        for hdr, value in headers.items():
+        for hdr, value in headers.iteritems():
             self.putheader(hdr, value)
         self.endheaders()
 
@@ -728,7 +745,7 @@ class HTTPConnection:
     def getresponse(self):
         "Get the response from the server."
 
-        # check if a prior response has been completed
+        # if a prior response has been completed, then forget about it.
         if self.__response and self.__response.isclosed():
             self.__response = None
 
@@ -753,9 +770,11 @@ class HTTPConnection:
 
         if self.debuglevel > 0:
             response = self.response_class(self.sock, self.debuglevel,
-                                           strict=self.strict)
+                                           strict=self.strict,
+                                           method=self._method)
         else:
-            response = self.response_class(self.sock, strict=self.strict)
+            response = self.response_class(self.sock, strict=self.strict,
+                                           method=self._method)
 
         response.begin()
         assert response.will_close != _UNKNOWN
@@ -830,7 +849,7 @@ class SSLFile(SharedSocketClient):
     def _read(self):
         buf = ''
         # put in a loop so that we retry on transient errors
-        while 1:
+        while True:
             try:
                 buf = self._ssl.read(self._bufsize)
             except socket.sslerror, err:
@@ -939,10 +958,7 @@ class HTTPSConnection(HTTPConnection):
 
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.connect((self.host, self.port))
-        realsock = sock
-        if hasattr(sock, "_sock"):
-            realsock = sock._sock
-        ssl = socket.ssl(realsock, self.key_file, self.cert_file)
+        ssl = socket.ssl(sock, self.key_file, self.cert_file)
         self.sock = FakeSocket(sock, ssl)
 
 
@@ -1130,7 +1146,7 @@ class LineAndFileWrapper:
     def _done(self):
         # called when the last byte is read from the line.  After the
         # call, all read methods are delegated to the underlying file
-        # obhect.
+        # object.
         self._line_consumed = 1
         self.read = self._file.read
         self.readline = self._file.readline
@@ -1214,8 +1230,6 @@ def test():
     if hasattr(socket, 'ssl'):
 
         for host, selector in (('sourceforge.net', '/projects/python'),
-                               ('dbserv2.theopalgroup.com', '/mediumfile'),
-                               ('dbserv2.theopalgroup.com', '/smallfile'),
                                ):
             print "https://%s%s" % (host, selector)
             hs = HTTPS()
@@ -1232,36 +1246,5 @@ def test():
                 for header in headers.headers: print header.strip()
             print
 
-    # Test a buggy server -- returns garbled status line.
-    # http://www.yahoo.com/promotions/mom_com97/supermom.html
-    c = HTTPConnection("promotions.yahoo.com")
-    c.set_debuglevel(1)
-    c.connect()
-    c.request("GET", "/promotions/mom_com97/supermom.html")
-    r = c.getresponse()
-    print r.status, r.version
-    lines = r.read().split("\n")
-    print "\n".join(lines[:5])
-
-    c = HTTPConnection("promotions.yahoo.com", strict=1)
-    c.set_debuglevel(1)
-    c.connect()
-    c.request("GET", "/promotions/mom_com97/supermom.html")
-    try:
-        r = c.getresponse()
-    except BadStatusLine, err:
-        print "strict mode failed as expected"
-        print err
-    else:
-        print "XXX strict mode should have failed"
-
-    for strict in 0, 1:
-        h = HTTP(strict=strict)
-        h.connect("promotions.yahoo.com")
-        h.putrequest('GET', "/promotions/mom_com97/supermom.html")
-        h.endheaders()
-        status, reason, headers = h.getreply()
-        assert (strict and status == -1) or status == 200, (strict, status)
-
 if __name__ == '__main__':
     test()
