@@ -1,4 +1,4 @@
-from test_support import verbose, have_unicode
+from test.test_support import verbose, have_unicode, TestFailed
 import sys
 
 # test string formatting operator (I am not sure if this is being tested
@@ -183,12 +183,12 @@ testboth("%#X", 0, "0X0")
 testboth("%#X", 0L, "0X0")
 
 testboth("%x", 0x42, "42")
-# testboth("%x", -0x42, "ffffffbe") # Alas, that's specific to 32-bit machines
+# testboth("%x", -0x42, "ffffffbe") # specific to 32-bit boxes; see below
 testboth("%x", 0x42L, "42")
 testboth("%x", -0x42L, "-42")
 
 testboth("%o", 042, "42")
-# testboth("%o", -042, "37777777736") # Alas, that's specific to 32-bit machines
+# testboth("%o", -042, "37777777736") # specific to 32-bit boxes; see below
 testboth("%o", 042L, "42")
 testboth("%o", -042L, "-42")
 
@@ -210,9 +210,34 @@ def test_exc(formatstr, args, exception, excmsg):
         if verbose: print 'no'
         print 'Unexpected exception'
         raise
+    else:
+        raise TestFailed, 'did not get expected exception: %s' % excmsg
 
 test_exc('abc %a', 1, ValueError,
          "unsupported format character 'a' (0x61) at index 5")
 if have_unicode:
     test_exc(unicode('abc %\u3000','raw-unicode-escape'), 1, ValueError,
              "unsupported format character '?' (0x3000) at index 5")
+
+test_exc('%d', '1', TypeError, "int argument required")
+test_exc('%g', '1', TypeError, "float argument required")
+test_exc('no format', '1', TypeError,
+         "not all arguments converted during string formatting")
+test_exc('no format', u'1', TypeError,
+         "not all arguments converted during string formatting")
+test_exc(u'no format', '1', TypeError,
+         "not all arguments converted during string formatting")
+test_exc(u'no format', u'1', TypeError,
+         "not all arguments converted during string formatting")
+
+if sys.maxint == 2**32-1:
+    # crashes 2.2.1 and earlier:
+    try:
+        "%*d"%(sys.maxint, -127)
+    except MemoryError:
+        pass
+    else:
+        raise TestFailed, '"%*d"%(sys.maxint, -127) should fail'
+    # (different things go wrong on a 64 bit box...)
+    testboth("%x", -0x42, "ffffffbe")
+    testboth("%o", -042, "37777777736")
